/*
 * Copyright (C) 2025, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: amingamingaming <wangyiming01@kylinos.cn>
 *
 */
import QtQuick 2.12
import QtQuick.Controls 2.5
import QtQuick.Templates 2.12 as T
import org.ukui.quick.items 1.0
import org.ukui.quick.platform 1.0

T.ScrollBar {
    id: control
    property bool visual: true
    property bool transparentMode: true
    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding)

    padding: (hovered || pressed) ? 4 : 6
    Behavior on padding {
        NumberAnimation {
            duration: 200
            easing.type: Easing.InOutQuad
        }
    }
    visible: control.policy !== T.ScrollBar.AlwaysOff
    minimumSize: orientation == Qt.Horizontal ? height / width : width / height

    contentItem: DtThemeBackground {
        implicitWidth: control.interactive ? 8 : 4
        implicitHeight: control.interactive ? 8 : 4
        radius: width / 2
        backgroundColor: getBackgroundColor()
        opacity: 0.0
    }

    states: State {
        name: "active"
        when: (control.policy !== T.ScrollBar.AlwaysOff || (control.active && control.size < 1.0)) && control.visual
    }

    transitions: [
        Transition {
            to: "active"
            NumberAnimation { targets: [control.contentItem]; property: "opacity"; to: 1.0 }
        },
        Transition {
            from: "active"
            SequentialAnimation {
                PropertyAction { targets: [control.contentItem]; property: "opacity"; value: 1.0 }
                NumberAnimation { targets: [control.contentItem]; property: "opacity"; to: 0.0 }
            }
        }
    ]

    function getBackgroundColor() {
        if(control.transparentMode) {
            return control.pressed ? GlobalTheme.kComponentAlphaClick :
                                     control.interactive && control.hovered ? GlobalTheme.kComponentAlphaHover
                                                                            : GlobalTheme.kComponentAlphaNormal
        } else {
            return control.pressed ? GlobalTheme.kComponentClick :
                                     control.interactive && control.hovered ? GlobalTheme.kComponentHover
                                                                            : GlobalTheme.kComponentNormal
        }
    }
}
