/*
 * Copyright (C) 2025, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: amingamingaming <wangyiming01@kylinos.cn>
 *
 */
import QtQuick 2.0
import QtQuick.Layouts 1.2
import QtQuick.Controls 2.12
import QtQuick.Templates 2.12 as T
import org.ukui.quick.items 1.0
import org.ukui.quick.platform 1.0

T.Slider {
    id: control
    property bool transparentMode: false
    property var backgroundColor : getBackgroundColor()
    property var borderColor : enabled ? GlobalTheme.kLineComponentNormal : GlobalTheme.kLineComponentDisable

    wheelEnabled: true

    Keys.onPressed: {
        if (event.key === Qt.Key_Left || event.key === Qt.Key_Down) {
            pressed = true
            if(mirrored) {
                increase()
            } else {
                decrease()
            }
            event.accepted = true;
        } else if (event.key === Qt.Key_Right || event.key === Qt.Key_Up) {
            pressed = true
            if(mirrored) {
                decrease()
            } else {
                increase()
            }
            event.accepted = true;
        }
    }
    Keys.onReleased: {
        pressed = false
        event.accepted = false;
    }

    function getBackgroundColor() {
        if(transparentMode) {
            return enabled ? GlobalTheme.kComponentAlphaNormal : GlobalTheme.kComponentAlphaDisable
        } else {
            return enabled ? GlobalTheme.kComponentNormal : GlobalTheme.kComponentDisable
        }
    }

    //进度条
    background: DtThemeBackground {
        id: sliderBackground
        x: control.leftPadding + (control.horizontal ? 0 : (control.availableWidth - width) / 2)
        y: control.topPadding + (control.horizontal ? (control.availableHeight - height) / 2 : 0)
        width: control.horizontal ? control.availableWidth : control.width
        height: control.horizontal ? control.height : control.availableHeight
        implicitWidth: control.width
        implicitHeight: control.height
        radius: control.horizontal ? height / 2 : width / 2
        useStyleTransparency: false
        backgroundColor: control.backgroundColor
        borderColor: control.borderColor
        border.width: 1
        scale: control.horizontal && control.mirrored ? -1 : 1
        DtThemeBackground {
            id: top
            x: control.horizontal ? 0 : (parent.width - width) / 2
            y: control.horizontal ? (parent.height - height) / 2 : control.visualPosition * (control.availableHeight - radius * 2)
            width: control.horizontal ? control.position * (control.availableWidth - radius * 2) + radius * 2 : control.width
            height: control.horizontal ? control.height : control.position * (control.availableHeight - radius * 2) + radius * 2
            radius: sliderBackground.radius
            useStyleTransparency: false
            backgroundColor: enabled ? GlobalTheme.kBrandNormal : GlobalTheme.kBrandDisable
            borderColor: enabled ? GlobalTheme.kLineBrandNormal : GlobalTheme.kLineBrandDisable
        }
    }

    //滑块
    handle: Item {
        id: sliderHandel
        x: control.horizontal ? control.visualPosition * (control.availableWidth - width) : control.availableWidth / 2 - width / 2
        y: control.horizontal ? control.availableHeight / 2 - height / 2 : control.visualPosition * (control.availableHeight - height)
        implicitWidth: control.horizontal ? control.height : control.width
        implicitHeight: control.horizontal ? control.height : control.width

        DtThemeBackground {
            id: whiteSpot
            width: control.horizontal ? (control.height / 16) * 4 : (control.width / 16) * 6
            height: control.horizontal ? (control.height / 16) * 6 : (control.width / 16) * 4
            radius: control.horizontal ? width / 2 : height / 2
            useStyleTransparency: false
            backgroundColor: GlobalTheme.kFontWhite
            anchors.centerIn: parent
        }
    }

}
